
Authors
=======

Main developer: Wolfgang Kopp (https://github.com/wkopp)

We are greatful for contributions from

* Annalaura Tamburrini (https://github.com/Annalaura94) for advancing the filtering options of the GenomicIndexer and for developing `plotGenomeTrack`.
